==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/class_v_s_t_g_u_i_1_1_c_frame.js <==
var class_v_s_t_g_u_i_1_1_c_frame =
[
    [ "CollectInvalidRects", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects" ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl" ],
    [ "EventProcessingFunction", "class_v_s_t_g_u_i_1_1_c_frame.html#a75b7be149a5ded19b0de8dcd72e3170d", null ],
    [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a6fa5f545ba9a08142895a94d8603d02f", null ],
    [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a2adc762721890dc5ff00ad13b5e57403", null ],
    [ "~CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a09fb3d19fdac5420d797c4e0133f641a", null ],
    [ "advanceNextFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#a5170494249a728ad6e8764de6cd461be", null ],
    [ "attached", "class_v_s_t_g_u_i_1_1_c_frame.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
    [ "beforeDelete", "class_v_s_t_g_u_i_1_1_c_frame.html#adc36f3faf62b04701b310c82c0b605a5", null ],
    [ "beginEdit", "class_v_s_t_g_u_i_1_1_c_frame.html#a6de7a2ecde27b7207ecdecc59c2b1ca7", null ],
    [ "beginModalViewSession", "class_v_s_t_g_u_i_1_1_c_frame.html#a67547f36b2f45aa34c8d7fd9a96ec880", null ],
    [ "callMouseObserverMouseEntered", "class_v_s_t_g_u_i_1_1_c_frame.html#a1f4ce6bc02521efb056d04c427c77336", null ],
    [ "callMouseObserverMouseExited", "class_v_s_t_g_u_i_1_1_c_frame.html#a8f97b9b5fe74666c47d1c374f265e60d", null ],
    [ "callMouseObserverOtherMouseEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a3402a32a2fd0efbfb2c3023bb151c025", null ],
    [ "checkMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#aa2412cc4f1e5a8fe430d2bb00c6f0b7d", null ],
    [ "clearMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a701c02ab4b91b1f30de6e7a7579854ca", null ],
    [ "close", "class_v_s_t_g_u_i_1_1_c_frame.html#a5ae591df94fc66ccb85cbb6565368bca", null ],
    [ "dispatchEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a685a52cd57a119d965aa3c6d2989dd94", null ],
    [ "dispatchKeyboardEventToHooks", "class_v_s_t_g_u_i_1_1_c_frame.html#a66a3aeaa87a1cc3dc4d24ce80be7819c", null ],
    [ "dispatchNewScaleFactor", "class_v_s_t_g_u_i_1_1_c_frame.html#a991d27d26592d2b00b8a6e30bd79a502", null ],
    [ "doAfterEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#a3b3f2dc1bd43a10e718ed1e057faebc1", null ],
    [ "doAfterEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#ab16da1317b758f94ed6e97d7d2edfd44", null ],
    [ "draw", "class_v_s_t_g_u_i_1_1_c_frame.html#a2223292a91c85ab8ff9d156763543bf2", null ],
    [ "drawRect", "class_v_s_t_g_u_i_1_1_c_frame.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
    [ "enableTooltips", "class_v_s_t_g_u_i_1_1_c_frame.html#a000b5244d4519d0d439b67d953ac62c0", null ],
    [ "endEdit", "class_v_s_t_g_u_i_1_1_c_frame.html#a71de5d264e5c0c8545565dd683cacbc2", null ],
    [ "endModalViewSession", "class_v_s_t_g_u_i_1_1_c_frame.html#ab7c73bc506048dc27e5f2290ffeac4a4", null ],
    [ "focusDrawingEnabled", "class_v_s_t_g_u_i_1_1_c_frame.html#a0acfe30fe0d0ca297d132808c772a6a1", null ],
    [ "frameToLocal", "class_v_s_t_g_u_i_1_1_c_frame.html#a48a051ae6394c5d724dd9bc50028c976", null ],
    [ "getAnimator", "class_v_s_t_g_u_i_1_1_c_frame.html#aa7609ca92096612f85c0fa58058bd2f8", null ],
    [ "getBitmapInterpolationQuality", "class_v_s_t_g_u_i_1_1_c_frame.html#afa66b21e807156a94cfb037dfe99bcc1", null ],
    [ "getClipboard", "class_v_s_t_g_u_i_1_1_c_frame.html#ae5a74bd429b29fb4cf849de18d9e1026", null ],
    [ "getContainerAt", "class_v_s_t_g_u_i_1_1_c_frame.html#a794fa3c4c824b618373db92342392168", null ],
    [ "getCurrentMouseButtons", "class_v_s_t_g_u_i_1_1_c_frame.html#aacb109245a1a30ed04f722a6544ef999", null ],
    [ "getCurrentMouseLocation", "class_v_s_t_g_u_i_1_1_c_frame.html#aff964a4f41381fec656a0e9cb4874792", null ],
    [ "getEditor", "class_v_s_t_g_u_i_1_1_c_frame.html#aeec44abf9f9ecf9c7a8d46d3c067cf58", null ],
    [ "getFocusColor", "class_v_s_t_g_u_i_1_1_c_frame.html#afeefe674d6bee18e3cfefa58b434e507", null ],
    [ "getFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#a9ac99d568f304d15c86f8b9dc8dd0314", null ],
    [ "getFocusWidth", "class_v_s_t_g_u_i_1_1_c_frame.html#ab3e90406aa3663a55236125c4296528f", null ],
    [ "getKnobMode", "class_v_s_t_g_u_i_1_1_c_frame.html#ad7ee35668bff338ff89ba36d1ca30fd7", null ],
    [ "getModalView", "class_v_s_t_g_u_i_1_1_c_frame.html#ab77989caa0f0d53bee2f6ade07fc8595", null ],
    [ "getPlatformFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a0677f29c0bd0f9c6ac3cad21a5fe81e0", null ],
    [ "getPosition", "class_v_s_t_g_u_i_1_1_c_frame.html#a104e6a8ff921eac3543ec51960eeda55", null ],
    [ "getScaleFactor", "class_v_s_t_g_u_i_1_1_c_frame.html#af3c4f7454d55d3056fa4ea442a01a23e", null ],
    [ "getSize", "class_v_s_t_g_u_i_1_1_c_frame.html#a1d7570642198aa2303ed7dda4e87fb83", null ],
    [ "getSize", "class_v_s_t_g_u_i_1_1_c_frame.html#ae862a8a124cc56131b2a01a1f02a6dee", null ],
    [ "getTicks", "class_v_s_t_g_u_i_1_1_c_frame.html#a5c714e38a1a6c603f421402d859d7f72", null ],
    [ "getViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#ac72db89ec9eed7ef306d59a5ff71e456", null ],
    [ "getViewAt", "class_v_s_t_g_u_i_1_1_c_frame.html#ae4fe024648ee2d08fac5bc564ec7c77d", null ],
    [ "getViewsAt", "class_v_s_t_g_u_i_1_1_c_frame.html#a1447cc2f1a606984cf21c6bf99460339", null ],
    [ "getZoom", "class_v_s_t_g_u_i_1_1_c_frame.html#a6ba639c95fbb18ad020f9eb4fb873e15", null ],
    [ "hitTestSubViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a3f0ab443e2da71397db40c66061ceaa4", null ],
    [ "idle", "class_v_s_t_g_u_i_1_1_c_frame.html#a83abbeda22fc5e6c2b35523b64199c1c", null ],
    [ "inEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#a6b4b2d5c7205cc8ebf18a030aeb28a08", null ],
    [ "invalid", "class_v_s_t_g_u_i_1_1_c_frame.html#a0a838991166299c2318eaf3fc6085005", null ],
    [ "invalidate", "class_v_s_t_g_u_i_1_1_c_frame.html#ad008bac973b8df24410908c5d0106503", null ],
    [ "invalidRect", "class_v_s_t_g_u_i_1_1_c_frame.html#a5803a16bd396a0d032c08c29a60e4f78", null ],
    [ "localToFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#ac578b2b9d3640fde24f011dd588e4f34", null ],
    [ "newCopy", "class_v_s_t_g_u_i_1_1_c_frame.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
    [ "onActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#aa5f22633746119816576e24fa9698978", null ],
    [ "onStartLocalEventLoop", "class_v_s_t_g_u_i_1_1_c_frame.html#add1b333f09c643945f8675bdbf094595", null ],
    [ "onViewAdded", "class_v_s_t_g_u_i_1_1_c_frame.html#a736d9acf1c3f5e81925cd1e49945682b", null ],
    [ "onViewRemoved", "class_v_s_t_g_u_i_1_1_c_frame.html#a062fdd8e28c1cbaeffa9e5ce6ca8f5ec", null ],
    [ "open", "class_v_s_t_g_u_i_1_1_c_frame.html#aa8975c5d50e8eadd2d091eec4a1a8756", null ],
    [ "performDrag", "class_v_s_t_g_u_i_1_1_c_frame.html#a3a5227c713cb76d053376057d3ec164b", null ],
    [ "platformDrawRects", "class_v_s_t_g_u_i_1_1_c_frame.html#a15cb9a517c6c2d6d8a4f1ff021bdd9a3", null ],
    [ "platformOnActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#a0262eb0830a81380a1970988cc4ccb40", null ],
    [ "platformOnDragEnter", "class_v_s_t_g_u_i_1_1_c_frame.html#a2ed1afc6fe8c0b6c026a504dd46b691d", null ],
    [ "platformOnDragLeave", "class_v_s_t_g_u_i_1_1_c_frame.html#adce58f8ff9f7d7c3791b0dc8fc5b9f78", null ],
    [ "platformOnDragMove", "class_v_s_t_g_u_i_1_1_c_frame.html#a0d80962a153027e245cfaa432a43c004", null ],
    [ "platformOnDrop", "class_v_s_t_g_u_i_1_1_c_frame.html#aa3734754e5805acf84773d8336212399", null ],
    [ "platformOnEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#aa136b9e220fd29bc6b230f15bfbc7ceb", null ],
    [ "platformOnWindowActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#a9a6344b0bad58075f4f9d146fce221a1", null ],
    [ "platformScaleFactorChanged", "class_v_s_t_g_u_i_1_1_c_frame.html#a5bd2d0c41f5d870ae5fd8896d9a7958a", null ],
    [ "registerFocusViewObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#ac37f8a2b1c23b14e598a15697919f9d9", null ],
    [ "registerKeyboardHook", "class_v_s_t_g_u_i_1_1_c_frame.html#a57e7f2c109fb40ae79918444fc19397f", null ],
    [ "registerMouseObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a55ab49640413da54e270e410a7dd8da9", null ],
    [ "registerScaleFactorChangedListeneer", "class_v_s_t_g_u_i_1_1_c_frame.html#a4731bf4d4e3436a3482ec9f2c82023eb", null ],
    [ "registerScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_c_frame.html#a4d77ab5870392e3b9b2ddae9a7e65c0e", null ],
    [ "removeAll", "class_v_s_t_g_u_i_1_1_c_frame.html#aabd341267925286a64dd52c16072e0cd", null ],
    [ "removeFromMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a8f5328af153c0e2cfff397131857b139", null ],
    [ "removeView", "class_v_s_t_g_u_i_1_1_c_frame.html#a628758060bb2b806776d7654c53768ca", null ],
    [ "scrollRect", "class_v_s_t_g_u_i_1_1_c_frame.html#adccf8c195f686e93c923333b54eace87", null ],
    [ "setBitmapInterpolationQuality", "class_v_s_t_g_u_i_1_1_c_frame.html#aab55ff6c1876660274fbdf90ec116085", null ],
    [ "setClipboard", "class_v_s_t_g_u_i_1_1_c_frame.html#a48e4b32a906a0accd7b9981fa085bb49", null ],
    [ "setCollectInvalidRects", "class_v_s_t_g_u_i_1_1_c_frame.html#a2c3865cc6313cb3595d1313eaee5fac8", null ],
    [ "setCursor", "class_v_s_t_g_u_i_1_1_c_frame.html#a3f7668c15f67ed4e7b9a27db9b95cb2b", null ],
    [ "setFocusColor", "class_v_s_t_g_u_i_1_1_c_frame.html#abecc63e92d16722ebcd412e30c6350cb", null ],
    [ "setFocusDrawingEnabled", "class_v_s_t_g_u_i_1_1_c_frame.html#a7447c9fa6124d6a7e3e8895335e2c337", null ],
    [ "setFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#af51b9124a814e6fd82fb4680ac58cff3", null ],
    [ "setFocusWidth", "class_v_s_t_g_u_i_1_1_c_frame.html#a04d8e61d75ad5cf40686349cba1be6df", null ],
    [ "setModalView", "class_v_s_t_g_u_i_1_1_c_frame.html#a8702ff2f7885f8d7a93bde675d32f1dc", null ],
    [ "setPosition", "class_v_s_t_g_u_i_1_1_c_frame.html#a9e48676aa6dfd2fe67df1a2671c7a92a", null ],
    [ "setSize", "class_v_s_t_g_u_i_1_1_c_frame.html#ae4d90a923646982d5b9bff95b46be728", null ],
    [ "setViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a073931d1b9f16b71db65f6843b6e9f17", null ],
    [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_frame.html#afa3d86320cb051cecb3c687a523ba787", null ],
    [ "setZoom", "class_v_s_t_g_u_i_1_1_c_frame.html#acd95b7a4f72bc2f26ec1b08904fd3df1", null ],
    [ "unregisterFocusViewObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a1f34157d8b33c38e237759e821c48820", null ],
    [ "unregisterKeyboardHook", "class_v_s_t_g_u_i_1_1_c_frame.html#a01d927d3fbbeec8aeeca48d4d8b44c34", null ],
    [ "unregisterMouseObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a0556144495a26b4b6c1c857cc3942ff4", null ],
    [ "unregisterScaleFactorChangedListeneer", "class_v_s_t_g_u_i_1_1_c_frame.html#acc3ae9665921a1ec7a4a3881b07a1d2a", null ],
    [ "unregisterScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_c_frame.html#a7ac8cbefe4ab2eb81af6b5704eeace5c", null ],
    [ "kDefaultKnobMode", "class_v_s_t_g_u_i_1_1_c_frame.html#afe15749e2ff50e7a5f332c825da699e3", null ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/class_v_s_t_g_u_i_1_1_c_frame.js <==
var class_v_s_t_g_u_i_1_1_c_frame =
[
    [ "CollectInvalidRects", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects.html", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_collect_invalid_rects" ],
    [ "Impl", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl" ],
    [ "EventProcessingFunction", "class_v_s_t_g_u_i_1_1_c_frame.html#a75b7be149a5ded19b0de8dcd72e3170d", null ],
    [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a6fa5f545ba9a08142895a94d8603d02f", null ],
    [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a2adc762721890dc5ff00ad13b5e57403", null ],
    [ "~CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a09fb3d19fdac5420d797c4e0133f641a", null ],
    [ "advanceNextFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#a5170494249a728ad6e8764de6cd461be", null ],
    [ "attached", "class_v_s_t_g_u_i_1_1_c_frame.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
    [ "beforeDelete", "class_v_s_t_g_u_i_1_1_c_frame.html#adc36f3faf62b04701b310c82c0b605a5", null ],
    [ "beginEdit", "class_v_s_t_g_u_i_1_1_c_frame.html#a6de7a2ecde27b7207ecdecc59c2b1ca7", null ],
    [ "beginModalViewSession", "class_v_s_t_g_u_i_1_1_c_frame.html#a67547f36b2f45aa34c8d7fd9a96ec880", null ],
    [ "callMouseObserverMouseEntered", "class_v_s_t_g_u_i_1_1_c_frame.html#a1f4ce6bc02521efb056d04c427c77336", null ],
    [ "callMouseObserverMouseExited", "class_v_s_t_g_u_i_1_1_c_frame.html#a8f97b9b5fe74666c47d1c374f265e60d", null ],
    [ "callMouseObserverOtherMouseEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a3402a32a2fd0efbfb2c3023bb151c025", null ],
    [ "checkMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#aa2412cc4f1e5a8fe430d2bb00c6f0b7d", null ],
    [ "checkSizeConstraint", "class_v_s_t_g_u_i_1_1_c_frame.html#a9ea5d0cad85b53c51e7c9ffa620eb26a", null ],
    [ "clearMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a701c02ab4b91b1f30de6e7a7579854ca", null ],
    [ "close", "class_v_s_t_g_u_i_1_1_c_frame.html#a5ae591df94fc66ccb85cbb6565368bca", null ],
    [ "dispatchEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a685a52cd57a119d965aa3c6d2989dd94", null ],
    [ "dispatchKeyboardEventToHooks", "class_v_s_t_g_u_i_1_1_c_frame.html#a66a3aeaa87a1cc3dc4d24ce80be7819c", null ],
    [ "dispatchNewScaleFactor", "class_v_s_t_g_u_i_1_1_c_frame.html#a991d27d26592d2b00b8a6e30bd79a502", null ],
    [ "doAfterEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#a3b3f2dc1bd43a10e718ed1e057faebc1", null ],
    [ "doAfterEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#ab16da1317b758f94ed6e97d7d2edfd44", null ],
    [ "draw", "class_v_s_t_g_u_i_1_1_c_frame.html#a2223292a91c85ab8ff9d156763543bf2", null ],
    [ "drawRect", "class_v_s_t_g_u_i_1_1_c_frame.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
    [ "enableTooltips", "class_v_s_t_g_u_i_1_1_c_frame.html#a000b5244d4519d0d439b67d953ac62c0", null ],
    [ "endEdit", "class_v_s_t_g_u_i_1_1_c_frame.html#a71de5d264e5c0c8545565dd683cacbc2", null ],
    [ "endModalViewSession", "class_v_s_t_g_u_i_1_1_c_frame.html#ab7c73bc506048dc27e5f2290ffeac4a4", null ],
    [ "focusDrawingEnabled", "class_v_s_t_g_u_i_1_1_c_frame.html#a0acfe30fe0d0ca297d132808c772a6a1", null ],
    [ "frameToLocal", "class_v_s_t_g_u_i_1_1_c_frame.html#a48a051ae6394c5d724dd9bc50028c976", null ],
    [ "getAnimator", "class_v_s_t_g_u_i_1_1_c_frame.html#aa7609ca92096612f85c0fa58058bd2f8", null ],
    [ "getBitmapInterpolationQuality", "class_v_s_t_g_u_i_1_1_c_frame.html#afa66b21e807156a94cfb037dfe99bcc1", null ],
    [ "getClipboard", "class_v_s_t_g_u_i_1_1_c_frame.html#ae5a74bd429b29fb4cf849de18d9e1026", null ],
    [ "getContainerAt", "class_v_s_t_g_u_i_1_1_c_frame.html#a794fa3c4c824b618373db92342392168", null ],
    [ "getCurrentMouseButtons", "class_v_s_t_g_u_i_1_1_c_frame.html#aacb109245a1a30ed04f722a6544ef999", null ],
    [ "getCurrentMouseLocation", "class_v_s_t_g_u_i_1_1_c_frame.html#aff964a4f41381fec656a0e9cb4874792", null ],
    [ "getEditor", "class_v_s_t_g_u_i_1_1_c_frame.html#aeec44abf9f9ecf9c7a8d46d3c067cf58", null ],
    [ "getFocusColor", "class_v_s_t_g_u_i_1_1_c_frame.html#afeefe674d6bee18e3cfefa58b434e507", null ],
    [ "getFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#a9ac99d568f304d15c86f8b9dc8dd0314", null ],
    [ "getFocusWidth", "class_v_s_t_g_u_i_1_1_c_frame.html#ab3e90406aa3663a55236125c4296528f", null ],
    [ "getKnobMode", "class_v_s_t_g_u_i_1_1_c_frame.html#ad7ee35668bff338ff89ba36d1ca30fd7", null ],
    [ "getModalView", "class_v_s_t_g_u_i_1_1_c_frame.html#ab77989caa0f0d53bee2f6ade07fc8595", null ],
    [ "getPlatformFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#a0677f29c0bd0f9c6ac3cad21a5fe81e0", null ],
    [ "getPosition", "class_v_s_t_g_u_i_1_1_c_frame.html#a104e6a8ff921eac3543ec51960eeda55", null ],
    [ "getScaleFactor", "class_v_s_t_g_u_i_1_1_c_frame.html#af3c4f7454d55d3056fa4ea442a01a23e", null ],
    [ "getSize", "class_v_s_t_g_u_i_1_1_c_frame.html#a1d7570642198aa2303ed7dda4e87fb83", null ],
    [ "getSize", "class_v_s_t_g_u_i_1_1_c_frame.html#ae862a8a124cc56131b2a01a1f02a6dee", null ],
    [ "getTicks", "class_v_s_t_g_u_i_1_1_c_frame.html#a5c714e38a1a6c603f421402d859d7f72", null ],
    [ "getViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#ac72db89ec9eed7ef306d59a5ff71e456", null ],
    [ "getViewAt", "class_v_s_t_g_u_i_1_1_c_frame.html#ae4fe024648ee2d08fac5bc564ec7c77d", null ],
    [ "getViewsAt", "class_v_s_t_g_u_i_1_1_c_frame.html#a1447cc2f1a606984cf21c6bf99460339", null ],
    [ "getZoom", "class_v_s_t_g_u_i_1_1_c_frame.html#a6ba639c95fbb18ad020f9eb4fb873e15", null ],
    [ "hitTestSubViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a3f0ab443e2da71397db40c66061ceaa4", null ],
    [ "idle", "class_v_s_t_g_u_i_1_1_c_frame.html#a83abbeda22fc5e6c2b35523b64199c1c", null ],
    [ "inEventProcessing", "class_v_s_t_g_u_i_1_1_c_frame.html#a6b4b2d5c7205cc8ebf18a030aeb28a08", null ],
    [ "invalid", "class_v_s_t_g_u_i_1_1_c_frame.html#a0a838991166299c2318eaf3fc6085005", null ],
    [ "invalidate", "class_v_s_t_g_u_i_1_1_c_frame.html#ad008bac973b8df24410908c5d0106503", null ],
    [ "invalidRect", "class_v_s_t_g_u_i_1_1_c_frame.html#a5803a16bd396a0d032c08c29a60e4f78", null ],
    [ "localToFrame", "class_v_s_t_g_u_i_1_1_c_frame.html#ac578b2b9d3640fde24f011dd588e4f34", null ],
    [ "newCopy", "class_v_s_t_g_u_i_1_1_c_frame.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
    [ "onActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#aa5f22633746119816576e24fa9698978", null ],
    [ "onStartLocalEventLoop", "class_v_s_t_g_u_i_1_1_c_frame.html#add1b333f09c643945f8675bdbf094595", null ],
    [ "onViewAdded", "class_v_s_t_g_u_i_1_1_c_frame.html#a736d9acf1c3f5e81925cd1e49945682b", null ],
    [ "onViewRemoved", "class_v_s_t_g_u_i_1_1_c_frame.html#a062fdd8e28c1cbaeffa9e5ce6ca8f5ec", null ],
    [ "open", "class_v_s_t_g_u_i_1_1_c_frame.html#aa8975c5d50e8eadd2d091eec4a1a8756", null ],
    [ "performDrag", "class_v_s_t_g_u_i_1_1_c_frame.html#a3a5227c713cb76d053376057d3ec164b", null ],
    [ "platformDrawRects", "class_v_s_t_g_u_i_1_1_c_frame.html#a15cb9a517c6c2d6d8a4f1ff021bdd9a3", null ],
    [ "platformOnActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#a0262eb0830a81380a1970988cc4ccb40", null ],
    [ "platformOnDragEnter", "class_v_s_t_g_u_i_1_1_c_frame.html#a2ed1afc6fe8c0b6c026a504dd46b691d", null ],
    [ "platformOnDragLeave", "class_v_s_t_g_u_i_1_1_c_frame.html#adce58f8ff9f7d7c3791b0dc8fc5b9f78", null ],
    [ "platformOnDragMove", "class_v_s_t_g_u_i_1_1_c_frame.html#a0d80962a153027e245cfaa432a43c004", null ],
    [ "platformOnDrop", "class_v_s_t_g_u_i_1_1_c_frame.html#aa3734754e5805acf84773d8336212399", null ],
    [ "platformOnEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#aa136b9e220fd29bc6b230f15bfbc7ceb", null ],
    [ "platformOnWindowActivate", "class_v_s_t_g_u_i_1_1_c_frame.html#a9a6344b0bad58075f4f9d146fce221a1", null ],
    [ "platformScaleFactorChanged", "class_v_s_t_g_u_i_1_1_c_frame.html#a5bd2d0c41f5d870ae5fd8896d9a7958a", null ],
    [ "registerFocusViewObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#ac37f8a2b1c23b14e598a15697919f9d9", null ],
    [ "registerKeyboardHook", "class_v_s_t_g_u_i_1_1_c_frame.html#a57e7f2c109fb40ae79918444fc19397f", null ],
    [ "registerMouseObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a55ab49640413da54e270e410a7dd8da9", null ],
    [ "registerScaleFactorChangedListeneer", "class_v_s_t_g_u_i_1_1_c_frame.html#a4731bf4d4e3436a3482ec9f2c82023eb", null ],
    [ "registerScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_c_frame.html#a4d77ab5870392e3b9b2ddae9a7e65c0e", null ],
    [ "removeAll", "class_v_s_t_g_u_i_1_1_c_frame.html#aabd341267925286a64dd52c16072e0cd", null ],
    [ "removeFromMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a8f5328af153c0e2cfff397131857b139", null ],
    [ "removeView", "class_v_s_t_g_u_i_1_1_c_frame.html#a628758060bb2b806776d7654c53768ca", null ],
    [ "scrollRect", "class_v_s_t_g_u_i_1_1_c_frame.html#adccf8c195f686e93c923333b54eace87", null ],
    [ "setBitmapInterpolationQuality", "class_v_s_t_g_u_i_1_1_c_frame.html#aab55ff6c1876660274fbdf90ec116085", null ],
    [ "setClipboard", "class_v_s_t_g_u_i_1_1_c_frame.html#a48e4b32a906a0accd7b9981fa085bb49", null ],
    [ "setCollectInvalidRects", "class_v_s_t_g_u_i_1_1_c_frame.html#a2c3865cc6313cb3595d1313eaee5fac8", null ],
    [ "setCursor", "class_v_s_t_g_u_i_1_1_c_frame.html#a3f7668c15f67ed4e7b9a27db9b95cb2b", null ],
    [ "setFocusColor", "class_v_s_t_g_u_i_1_1_c_frame.html#abecc63e92d16722ebcd412e30c6350cb", null ],
    [ "setFocusDrawingEnabled", "class_v_s_t_g_u_i_1_1_c_frame.html#a7447c9fa6124d6a7e3e8895335e2c337", null ],
    [ "setFocusView", "class_v_s_t_g_u_i_1_1_c_frame.html#af51b9124a814e6fd82fb4680ac58cff3", null ],
    [ "setFocusWidth", "class_v_s_t_g_u_i_1_1_c_frame.html#a04d8e61d75ad5cf40686349cba1be6df", null ],
    [ "setModalView", "class_v_s_t_g_u_i_1_1_c_frame.html#a8702ff2f7885f8d7a93bde675d32f1dc", null ],
    [ "setPosition", "class_v_s_t_g_u_i_1_1_c_frame.html#a9e48676aa6dfd2fe67df1a2671c7a92a", null ],
    [ "setSize", "class_v_s_t_g_u_i_1_1_c_frame.html#ae4d90a923646982d5b9bff95b46be728", null ],
    [ "setViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a073931d1b9f16b71db65f6843b6e9f17", null ],
    [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_frame.html#afa3d86320cb051cecb3c687a523ba787", null ],
    [ "setZoom", "class_v_s_t_g_u_i_1_1_c_frame.html#acd95b7a4f72bc2f26ec1b08904fd3df1", null ],
    [ "unregisterFocusViewObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a1f34157d8b33c38e237759e821c48820", null ],
    [ "unregisterKeyboardHook", "class_v_s_t_g_u_i_1_1_c_frame.html#a01d927d3fbbeec8aeeca48d4d8b44c34", null ],
    [ "unregisterMouseObserver", "class_v_s_t_g_u_i_1_1_c_frame.html#a0556144495a26b4b6c1c857cc3942ff4", null ],
    [ "unregisterScaleFactorChangedListeneer", "class_v_s_t_g_u_i_1_1_c_frame.html#acc3ae9665921a1ec7a4a3881b07a1d2a", null ],
    [ "unregisterScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_c_frame.html#a7ac8cbefe4ab2eb81af6b5704eeace5c", null ],
    [ "kDefaultKnobMode", "class_v_s_t_g_u_i_1_1_c_frame.html#afe15749e2ff50e7a5f332c825da699e3", null ]
];
